==> conntrack_0.9.12.orig.tar.gz: conntrack-tools-0.9.12/src/read_config_yy.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     T_IPV4_ADDR = 258,
     T_IPV4_IFACE = 259,
     T_PORT = 260,
     T_HASHSIZE = 261,
     T_HASHLIMIT = 262,
     T_MULTICAST = 263,
     T_PATH = 264,
     T_UNIX = 265,
     T_REFRESH = 266,
     T_IPV6_ADDR = 267,
     T_IPV6_IFACE = 268,
     T_IGNORE_UDP = 269,
     T_IGNORE_ICMP = 270,
     T_IGNORE_TRAFFIC = 271,
     T_BACKLOG = 272,
     T_GROUP = 273,
     T_LOG = 274,
     T_UDP = 275,
     T_ICMP = 276,
     T_IGMP = 277,
     T_VRRP = 278,
     T_IGNORE_PROTOCOL = 279,
     T_LOCK = 280,
     T_STRIP_NAT = 281,
     T_BUFFER_SIZE_MAX_GROWN = 282,
     T_EXPIRE = 283,
     T_TIMEOUT = 284,
     T_GENERAL = 285,
     T_SYNC = 286,
     T_STATS = 287,
     T_RELAX_TRANSITIONS = 288,
     T_BUFFER_SIZE = 289,
     T_DELAY = 290,
     T_SYNC_MODE = 291,
     T_LISTEN_TO = 292,
     T_FAMILY = 293,
     T_RESEND_BUFFER_SIZE = 294,
     T_ALARM = 295,
     T_FTFW = 296,
     T_CHECKSUM = 297,
     T_WINDOWSIZE = 298,
     T_ON = 299,
     T_OFF = 300,
     T_REPLICATE = 301,
     T_FOR = 302,
     T_IFACE = 303,
     T_PURGE = 304,
     T_RESEND_QUEUE_SIZE = 305,
     T_ESTABLISHED = 306,
     T_SYN_SENT = 307,
     T_SYN_RECV = 308,
     T_FIN_WAIT = 309,
     T_CLOSE_WAIT = 310,
     T_LAST_ACK = 311,
     T_TIME_WAIT = 312,
     T_CLOSE = 313,
     T_LISTEN = 314,
     T_SYSLOG = 315,
     T_WRITE_THROUGH = 316,
     T_STAT_BUFFER_SIZE = 317,
     T_DESTROY_TIMEOUT = 318,
     T_RCVBUFF = 319,
     T_SNDBUFF = 320,
     T_NOTRACK = 321,
     T_POLL_SECS = 322,
     T_FILTER = 323,
     T_ADDRESS = 324,
     T_PROTOCOL = 325,
     T_STATE = 326,
     T_ACCEPT = 327,
     T_IGNORE = 328,
     T_FROM = 329,
     T_USERSPACE = 330,
     T_KERNELSPACE = 331,
     T_EVENT_ITER_LIMIT = 332,
     T_DEFAULT = 333,
     T_NETLINK_OVERRUN_RESYNC = 334,
     T_NICE = 335,
     T_IPV4_DEST_ADDR = 336,
     T_IPV6_DEST_ADDR = 337,
     T_IP = 338,
     T_PATH_VAL = 339,
     T_NUMBER = 340,
     T_SIGNED_NUMBER = 341,
     T_STRING = 342
   };
#endif
/* Tokens.  */
#define T_IPV4_ADDR 258
#define T_IPV4_IFACE 259
#define T_PORT 260
#define T_HASHSIZE 261
#define T_HASHLIMIT 262
#define T_MULTICAST 263
#define T_PATH 264
#define T_UNIX 265
#define T_REFRESH 266
#define T_IPV6_ADDR 267
#define T_IPV6_IFACE 268
#define T_IGNORE_UDP 269
#define T_IGNORE_ICMP 270
#define T_IGNORE_TRAFFIC 271
#define T_BACKLOG 272
#define T_GROUP 273
#define T_LOG 274
#define T_UDP 275
#define T_ICMP 276
#define T_IGMP 277
#define T_VRRP 278
#define T_IGNORE_PROTOCOL 279
#define T_LOCK 280
#define T_STRIP_NAT 281
#define T_BUFFER_SIZE_MAX_GROWN 282
#define T_EXPIRE 283
#define T_TIMEOUT 284
#define T_GENERAL 285
#define T_SYNC 286
#define T_STATS 287
#define T_RELAX_TRANSITIONS 288
#define T_BUFFER_SIZE 289
#define T_DELAY 290
#define T_SYNC_MODE 291
#define T_LISTEN_TO 292
#define T_FAMILY 293
#define T_RESEND_BUFFER_SIZE 294
#define T_ALARM 295
#define T_FTFW 296
#define T_CHECKSUM 297
#define T_WINDOWSIZE 298
#define T_ON 299
#define T_OFF 300
#define T_REPLICATE 301
#define T_FOR 302
#define T_IFACE 303
#define T_PURGE 304
#define T_RESEND_QUEUE_SIZE 305
#define T_ESTABLISHED 306
#define T_SYN_SENT 307
#define T_SYN_RECV 308
#define T_FIN_WAIT 309
#define T_CLOSE_WAIT 310
#define T_LAST_ACK 311
#define T_TIME_WAIT 312
#define T_CLOSE 313
#define T_LISTEN 314
#define T_SYSLOG 315
#define T_WRITE_THROUGH 316
#define T_STAT_BUFFER_SIZE 317
#define T_DESTROY_TIMEOUT 318
#define T_RCVBUFF 319
#define T_SNDBUFF 320
#define T_NOTRACK 321
#define T_POLL_SECS 322
#define T_FILTER 323
#define T_ADDRESS 324
#define T_PROTOCOL 325
#define T_STATE 326
#define T_ACCEPT 327
#define T_IGNORE 328
#define T_FROM 329
#define T_USERSPACE 330
#define T_KERNELSPACE 331
#define T_EVENT_ITER_LIMIT 332
#define T_DEFAULT 333
#define T_NETLINK_OVERRUN_RESYNC 334
#define T_NICE 335
#define T_IPV4_DEST_ADDR 336
#define T_IPV6_DEST_ADDR 337
#define T_IP 338
#define T_PATH_VAL 339
#define T_NUMBER 340
#define T_SIGNED_NUMBER 341
#define T_STRING 342




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 52 "read_config_yy.y"
{
	int		val;
	char		*string;
}
/* Line 1489 of yacc.c.  */
#line 228 "read_config_yy.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

==> conntrack_0.9.13.orig.tar.gz: conntrack-tools-0.9.13/src/read_config_yy.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     T_IPV4_ADDR = 258,
     T_IPV4_IFACE = 259,
     T_PORT = 260,
     T_HASHSIZE = 261,
     T_HASHLIMIT = 262,
     T_MULTICAST = 263,
     T_PATH = 264,
     T_UNIX = 265,
     T_REFRESH = 266,
     T_IPV6_ADDR = 267,
     T_IPV6_IFACE = 268,
     T_IGNORE_UDP = 269,
     T_IGNORE_ICMP = 270,
     T_IGNORE_TRAFFIC = 271,
     T_BACKLOG = 272,
     T_GROUP = 273,
     T_LOG = 274,
     T_UDP = 275,
     T_ICMP = 276,
     T_IGMP = 277,
     T_VRRP = 278,
     T_IGNORE_PROTOCOL = 279,
     T_LOCK = 280,
     T_STRIP_NAT = 281,
     T_BUFFER_SIZE_MAX_GROWN = 282,
     T_EXPIRE = 283,
     T_TIMEOUT = 284,
     T_GENERAL = 285,
     T_SYNC = 286,
     T_STATS = 287,
     T_RELAX_TRANSITIONS = 288,
     T_BUFFER_SIZE = 289,
     T_DELAY = 290,
     T_SYNC_MODE = 291,
     T_LISTEN_TO = 292,
     T_FAMILY = 293,
     T_RESEND_BUFFER_SIZE = 294,
     T_ALARM = 295,
     T_FTFW = 296,
     T_CHECKSUM = 297,
     T_WINDOWSIZE = 298,
     T_ON = 299,
     T_OFF = 300,
     T_REPLICATE = 301,
     T_FOR = 302,
     T_IFACE = 303,
     T_PURGE = 304,
     T_RESEND_QUEUE_SIZE = 305,
     T_ESTABLISHED = 306,
     T_SYN_SENT = 307,
     T_SYN_RECV = 308,
     T_FIN_WAIT = 309,
     T_CLOSE_WAIT = 310,
     T_LAST_ACK = 311,
     T_TIME_WAIT = 312,
     T_CLOSE = 313,
     T_LISTEN = 314,
     T_SYSLOG = 315,
     T_WRITE_THROUGH = 316,
     T_STAT_BUFFER_SIZE = 317,
     T_DESTROY_TIMEOUT = 318,
     T_RCVBUFF = 319,
     T_SNDBUFF = 320,
     T_NOTRACK = 321,
     T_POLL_SECS = 322,
     T_FILTER = 323,
     T_ADDRESS = 324,
     T_PROTOCOL = 325,
     T_STATE = 326,
     T_ACCEPT = 327,
     T_IGNORE = 328,
     T_FROM = 329,
     T_USERSPACE = 330,
     T_KERNELSPACE = 331,
     T_EVENT_ITER_LIMIT = 332,
     T_DEFAULT = 333,
     T_NETLINK_OVERRUN_RESYNC = 334,
     T_NICE = 335,
     T_IPV4_DEST_ADDR = 336,
     T_IPV6_DEST_ADDR = 337,
     T_SCHEDULER = 338,
     T_TYPE = 339,
     T_PRIO = 340,
     T_IP = 341,
     T_PATH_VAL = 342,
     T_NUMBER = 343,
     T_SIGNED_NUMBER = 344,
     T_STRING = 345
   };
#endif
/* Tokens.  */
#define T_IPV4_ADDR 258
#define T_IPV4_IFACE 259
#define T_PORT 260
#define T_HASHSIZE 261
#define T_HASHLIMIT 262
#define T_MULTICAST 263
#define T_PATH 264
#define T_UNIX 265
#define T_REFRESH 266
#define T_IPV6_ADDR 267
#define T_IPV6_IFACE 268
#define T_IGNORE_UDP 269
#define T_IGNORE_ICMP 270
#define T_IGNORE_TRAFFIC 271
#define T_BACKLOG 272
#define T_GROUP 273
#define T_LOG 274
#define T_UDP 275
#define T_ICMP 276
#define T_IGMP 277
#define T_VRRP 278
#define T_IGNORE_PROTOCOL 279
#define T_LOCK 280
#define T_STRIP_NAT 281
#define T_BUFFER_SIZE_MAX_GROWN 282
#define T_EXPIRE 283
#define T_TIMEOUT 284
#define T_GENERAL 285
#define T_SYNC 286
#define T_STATS 287
#define T_RELAX_TRANSITIONS 288
#define T_BUFFER_SIZE 289
#define T_DELAY 290
#define T_SYNC_MODE 291
#define T_LISTEN_TO 292
#define T_FAMILY 293
#define T_RESEND_BUFFER_SIZE 294
#define T_ALARM 295
#define T_FTFW 296
#define T_CHECKSUM 297
#define T_WINDOWSIZE 298
#define T_ON 299
#define T_OFF 300
#define T_REPLICATE 301
#define T_FOR 302
#define T_IFACE 303
#define T_PURGE 304
#define T_RESEND_QUEUE_SIZE 305
#define T_ESTABLISHED 306
#define T_SYN_SENT 307
#define T_SYN_RECV 308
#define T_FIN_WAIT 309
#define T_CLOSE_WAIT 310
#define T_LAST_ACK 311
#define T_TIME_WAIT 312
#define T_CLOSE 313
#define T_LISTEN 314
#define T_SYSLOG 315
#define T_WRITE_THROUGH 316
#define T_STAT_BUFFER_SIZE 317
#define T_DESTROY_TIMEOUT 318
#define T_RCVBUFF 319
#define T_SNDBUFF 320
#define T_NOTRACK 321
#define T_POLL_SECS 322
#define T_FILTER 323
#define T_ADDRESS 324
#define T_PROTOCOL 325
#define T_STATE 326
#define T_ACCEPT 327
#define T_IGNORE 328
#define T_FROM 329
#define T_USERSPACE 330
#define T_KERNELSPACE 331
#define T_EVENT_ITER_LIMIT 332
#define T_DEFAULT 333
#define T_NETLINK_OVERRUN_RESYNC 334
#define T_NICE 335
#define T_IPV4_DEST_ADDR 336
#define T_IPV6_DEST_ADDR 337
#define T_SCHEDULER 338
#define T_TYPE 339
#define T_PRIO 340
#define T_IP 341
#define T_PATH_VAL 342
#define T_NUMBER 343
#define T_SIGNED_NUMBER 344
#define T_STRING 345




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 53 "read_config_yy.y"
{
	int		val;
	char		*string;
}
/* Line 1489 of yacc.c.  */
#line 234 "read_config_yy.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;
